API
===

asya.cli
--------

.. automodule:: asya.cli
   :members:

asya.exceptions
---------------

.. automodule:: asya.exceptions
   :members:

asya.logic
----------

.. important:: This is the module to be implemented!

.. automodule:: asya.logic
   :members: gather_acquaintances

asya.supervisor
---------------

.. automodule:: asya.supervisor
   :members:

